@@ -303,12 +303,14 @@ class PgStorage(SqlStorage):
                              " AND viewname = %s", (self.session_id, viewname))
         viewdef = cursor.fetchone()
         if viewdef:
-            stmt = viewdef['definition'].rstrip(';')
+            stmt = viewdef['definition'].rstrip(';').replace('\n', ' ')
 
             # PostgreSQL will "expand" the original "*" to the columns
             # that existed at that time.  We need to get the star back, to
             # match SQLite3's behavior.
-            return re.sub(r'^.*?FROM', 'SELECT * FROM', stmt, 1, re.DOTALL)
+            otype = self.table_type(viewname)
+            return re.sub(f"SELECT *(\"?{otype}\"?\\.['A-Za-z09_\\.-]+,? *)+ FROM",
+                          "SELECT * FROM", stmt)
 
         # Must be a table
         return f'SELECT * FROM "{viewname}"'
